#include "motor.h"
#include "oled.h"

void set_motor_voltage(uint8_t id, motor_t *motor1, motor_t *motor2, motor_t *motor3, motor_t *motor4) {
    int16_t sp1, sp2, sp3, sp4;
    uint16_t tx_id, can_id;
    sp1 = sp2 = sp3 = sp4 = 0;
    tx_id = id;

    if (motor1) { sp1 = correct_output(motor1); }
    if (motor2) { sp2 = correct_output(motor2); }
    if (motor3) { sp3 = correct_output(motor3); }
    if (motor4) { sp4 = correct_output(motor4); }
		
		can1_transmit(tx_id, sp1, sp2, sp3, sp4);
}


static int16_t correct_output(motor_t *motor) {
    return motor->voltage;
}

uint8_t get_motor_data(motor_t *motor) {
    uint8_t buf[CAN_DATA_SIZE];
    can1_read(motor->can_info.rx_id, buf);
		oled_printf(1,1,"Val: %i", buf[2]);
	
    switch (motor->type) {
			case GM6020:
				get_6020_data(motor, buf);
				return 1;
			default:
				return 0;
    }
}


static void get_6020_data(motor_t* motor, uint8_t buf[CAN_DATA_SIZE]){
	motor->info.GM6020_info.angle = (int16_t)(buf[0] << 8 | buf[1]);
	motor->info.GM6020_info.speed = (int16_t)(buf[2] << 8 | buf[3]);
	motor->info.GM6020_info.current = (int16_t)(buf[4] << 8 | buf[5]);
	motor->info.GM6020_info.temp = (int8_t)(buf[6]);
}